/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<Sensor.h>)
#  include <Sensor.h>
#endif
#if __has_include(<SensorDataModel.h>)
#  include <SensorDataModel.h>
#endif
#if __has_include(<SensorTreeModel.h>)
#  include <SensorTreeModel.h>
#endif
#if __has_include(<SensorUnitModel.h>)
#  include <SensorUnitModel.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_ksysguard_sensors()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<KSysGuard::Sensor>("org.kde.ksysguard.sensors", 1);
    qmlRegisterEnum<KSysGuard::Sensor::Status>("KSysGuard::Sensor::Status");
    qmlRegisterTypesAndRevisions<KSysGuard::SensorDataModel>("org.kde.ksysguard.sensors", 1);
    qmlRegisterEnum<KSysGuard::SensorDataModel::AdditionalRoles>("KSysGuard::SensorDataModel::AdditionalRoles");
    qmlRegisterTypesAndRevisions<KSysGuard::SensorTreeModel>("org.kde.ksysguard.sensors", 1);
    qmlRegisterEnum<KSysGuard::SensorTreeModel::AdditionalRoles>("KSysGuard::SensorTreeModel::AdditionalRoles");
    qmlRegisterTypesAndRevisions<KSysGuard::SensorUnitModel>("org.kde.ksysguard.sensors", 1);
    qmlRegisterEnum<KSysGuard::SensorUnitModel::Roles>("KSysGuard::SensorUnitModel::Roles");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QMetaType::fromType<QAbstractTableModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.ksysguard.sensors", 1, 0);
}

static const QQmlModuleRegistration orgkdeksysguardsensorsRegistration("org.kde.ksysguard.sensors", qml_register_types_org_kde_ksysguard_sensors);
