/****************************************************************************
** Meta object code from reading C++ file 'SensorFaceController.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksysguard-6.7.4/faces/SensorFaceController.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SensorFaceController.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KSysGuard20SensorFaceControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::SensorFaceController::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard20SensorFaceControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::SensorFaceController",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "It's not possible to create objects of type SensorFaceController",
        "faceIdChanged",
        "",
        "titleChanged",
        "showTitleChanged",
        "totalSensorsChanged",
        "highPrioritySensorIdsChanged",
        "lowPrioritySensorIdsChanged",
        "sensorsChanged",
        "sensorColorsChanged",
        "sensorLabelsChanged",
        "updateRateLimitChanged",
        "faceConfigurationChanged",
        "missingSensorsChanged",
        "reloadConfig",
        "loadPreset",
        "preset",
        "savePreset",
        "uninstallPreset",
        "pluginId",
        "reloadFaceConfiguration",
        "replaceSensors",
        "from",
        "to",
        "title",
        "showTitle",
        "faceId",
        "totalSensors",
        "QJsonArray",
        "highPrioritySensorIds",
        "sensorColors",
        "QVariantMap",
        "sensorLabels",
        "lowPrioritySensorIds",
        "name",
        "icon",
        "supportsSensorsColors",
        "supportsTotalSensors",
        "supportsLowPrioritySensors",
        "maxTotalSensors",
        "faceConfiguration",
        "KConfigPropertyMap*",
        "fullRepresentation",
        "QQuickItem*",
        "compactRepresentation",
        "faceConfigUi",
        "appearanceConfigUi",
        "sensorsConfigUi",
        "availableFacesModel",
        "QAbstractItemModel*",
        "availablePresetsModel",
        "updateRateLimit",
        "missingSensors"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'faceIdChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTitleChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'totalSensorsChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'highPrioritySensorIdsChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lowPrioritySensorIdsChanged'
        QtMocHelpers::SignalData<void()>(13, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sensorsChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sensorColorsChanged'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sensorLabelsChanged'
        QtMocHelpers::SignalData<void()>(16, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateRateLimitChanged'
        QtMocHelpers::SignalData<void()>(17, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'faceConfigurationChanged'
        QtMocHelpers::SignalData<void()>(18, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'missingSensorsChanged'
        QtMocHelpers::SignalData<void()>(19, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'reloadConfig'
        QtMocHelpers::MethodData<void()>(20, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'loadPreset'
        QtMocHelpers::MethodData<void(const QString &)>(21, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Method 'savePreset'
        QtMocHelpers::MethodData<void()>(23, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'uninstallPreset'
        QtMocHelpers::MethodData<void(const QString &)>(24, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Method 'reloadFaceConfiguration'
        QtMocHelpers::MethodData<void()>(26, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'replaceSensors'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(27, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'title'
        QtMocHelpers::PropertyData<QString>(30, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'showTitle'
        QtMocHelpers::PropertyData<bool>(31, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'faceId'
        QtMocHelpers::PropertyData<QString>(32, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'totalSensors'
        QtMocHelpers::PropertyData<QJsonArray>(33, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'highPrioritySensorIds'
        QtMocHelpers::PropertyData<QJsonArray>(35, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'sensorColors'
        QtMocHelpers::PropertyData<QVariantMap>(36, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'sensorLabels'
        QtMocHelpers::PropertyData<QVariantMap>(38, 0x80000000 | 37, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 8),
        // property 'lowPrioritySensorIds'
        QtMocHelpers::PropertyData<QJsonArray>(39, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(40, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'icon'
        QtMocHelpers::PropertyData<QString>(41, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'supportsSensorsColors'
        QtMocHelpers::PropertyData<bool>(42, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'supportsTotalSensors'
        QtMocHelpers::PropertyData<bool>(43, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'supportsLowPrioritySensors'
        QtMocHelpers::PropertyData<bool>(44, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
        // property 'maxTotalSensors'
        QtMocHelpers::PropertyData<int>(45, QMetaType::Int, QMC::DefaultPropertyFlags, 0),
        // property 'faceConfiguration'
        QtMocHelpers::PropertyData<KConfigPropertyMap*>(46, 0x80000000 | 47, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 10),
        // property 'fullRepresentation'
        QtMocHelpers::PropertyData<QQuickItem*>(48, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'compactRepresentation'
        QtMocHelpers::PropertyData<QQuickItem*>(50, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'faceConfigUi'
        QtMocHelpers::PropertyData<QQuickItem*>(51, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'appearanceConfigUi'
        QtMocHelpers::PropertyData<QQuickItem*>(52, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'sensorsConfigUi'
        QtMocHelpers::PropertyData<QQuickItem*>(53, 0x80000000 | 49, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 0),
        // property 'availableFacesModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(54, 0x80000000 | 55, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'availablePresetsModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(56, 0x80000000 | 55, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'updateRateLimit'
        QtMocHelpers::PropertyData<int>(57, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'missingSensors'
        QtMocHelpers::PropertyData<QJsonArray>(58, 0x80000000 | 34, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 11),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<SensorFaceController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KSysGuard::SensorFaceController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard20SensorFaceControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard20SensorFaceControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KSysGuard20SensorFaceControllerE_t>.metaTypes,
    nullptr
} };

void KSysGuard::SensorFaceController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SensorFaceController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->faceIdChanged(); break;
        case 1: _t->titleChanged(); break;
        case 2: _t->showTitleChanged(); break;
        case 3: _t->totalSensorsChanged(); break;
        case 4: _t->highPrioritySensorIdsChanged(); break;
        case 5: _t->lowPrioritySensorIdsChanged(); break;
        case 6: _t->sensorsChanged(); break;
        case 7: _t->sensorColorsChanged(); break;
        case 8: _t->sensorLabelsChanged(); break;
        case 9: _t->updateRateLimitChanged(); break;
        case 10: _t->faceConfigurationChanged(); break;
        case 11: _t->missingSensorsChanged(); break;
        case 12: _t->reloadConfig(); break;
        case 13: _t->loadPreset((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->savePreset(); break;
        case 15: _t->uninstallPreset((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->reloadFaceConfiguration(); break;
        case 17: _t->replaceSensors((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::faceIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::titleChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::showTitleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::totalSensorsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::highPrioritySensorIdsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::lowPrioritySensorIdsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::sensorsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::sensorColorsChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::sensorLabelsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::updateRateLimitChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::faceConfigurationChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorFaceController::*)()>(_a, &SensorFaceController::missingSensorsChanged, 11))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 21:
        case 20:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        case 19:
        case 18:
        case 17:
        case 16:
        case 15:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQuickItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->title(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->showTitle(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->faceId(); break;
        case 3: *reinterpret_cast<QJsonArray*>(_v) = _t->totalSensors(); break;
        case 4: *reinterpret_cast<QJsonArray*>(_v) = _t->highPrioritySensorIds(); break;
        case 5: *reinterpret_cast<QVariantMap*>(_v) = _t->sensorColors(); break;
        case 6: *reinterpret_cast<QVariantMap*>(_v) = _t->sensorLabels(); break;
        case 7: *reinterpret_cast<QJsonArray*>(_v) = _t->lowPrioritySensorIds(); break;
        case 8: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->icon(); break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->supportsSensorsColors(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->supportsTotalSensors(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->supportsLowPrioritySensors(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->maxTotalSensors(); break;
        case 14: *reinterpret_cast<KConfigPropertyMap**>(_v) = _t->faceConfiguration(); break;
        case 15: *reinterpret_cast<QQuickItem**>(_v) = _t->fullRepresentation(); break;
        case 16: *reinterpret_cast<QQuickItem**>(_v) = _t->compactRepresentation(); break;
        case 17: *reinterpret_cast<QQuickItem**>(_v) = _t->faceConfigUi(); break;
        case 18: *reinterpret_cast<QQuickItem**>(_v) = _t->appearanceConfigUi(); break;
        case 19: *reinterpret_cast<QQuickItem**>(_v) = _t->sensorsConfigUi(); break;
        case 20: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->availableFacesModel(); break;
        case 21: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->availablePresetsModel(); break;
        case 22: *reinterpret_cast<int*>(_v) = _t->updateRateLimit(); break;
        case 23: *reinterpret_cast<QJsonArray*>(_v) = _t->missingSensors(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTitle(*reinterpret_cast<QString*>(_v)); break;
        case 1: _t->setShowTitle(*reinterpret_cast<bool*>(_v)); break;
        case 2: _t->setFaceId(*reinterpret_cast<QString*>(_v)); break;
        case 3: _t->setTotalSensors(*reinterpret_cast<QJsonArray*>(_v)); break;
        case 4: _t->setHighPrioritySensorIds(*reinterpret_cast<QJsonArray*>(_v)); break;
        case 5: _t->setSensorColors(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 6: _t->setSensorLabels(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 7: _t->setLowPrioritySensorIds(*reinterpret_cast<QJsonArray*>(_v)); break;
        case 22: _t->setUpdateRateLimit(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KSysGuard::SensorFaceController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSysGuard::SensorFaceController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard20SensorFaceControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KSysGuard::SensorFaceController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void KSysGuard::SensorFaceController::faceIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSysGuard::SensorFaceController::titleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KSysGuard::SensorFaceController::showTitleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSysGuard::SensorFaceController::totalSensorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KSysGuard::SensorFaceController::highPrioritySensorIdsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KSysGuard::SensorFaceController::lowPrioritySensorIdsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KSysGuard::SensorFaceController::sensorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KSysGuard::SensorFaceController::sensorColorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KSysGuard::SensorFaceController::sensorLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KSysGuard::SensorFaceController::updateRateLimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KSysGuard::SensorFaceController::faceConfigurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KSysGuard::SensorFaceController::missingSensorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
