/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<FormatterWrapper.h>)
#  include <FormatterWrapper.h>
#endif
#if __has_include(<Unit.h>)
#  include <Unit.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_ksysguard_formatter()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KSysGuard::staticMetaObject;},
            "KSysGuard");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KSysGuard::staticMetaObject, "org.kde.ksysguard.formatter", 1, nullptr, &KSysGuard::staticMetaObject, nullptr);
    qmlRegisterEnum<KSysGuard::MetricPrefix>("KSysGuard::MetricPrefix");
    qmlRegisterEnum<KSysGuard::Unit>("KSysGuard::Unit");
    qmlRegisterTypesAndRevisions<KSysGuard::FormatterWrapper>("org.kde.ksysguard.formatter", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.kde.ksysguard.formatter", 1, 0);
}

static const QQmlModuleRegistration orgkdeksysguardformatterRegistration("org.kde.ksysguard.formatter", qml_register_types_org_kde_ksysguard_formatter);
