/****************************************************************************
** Meta object code from reading C++ file 'SensorDataModel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksysguard-6.7.4/sensors/SensorDataModel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'SensorDataModel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KSysGuard15SensorDataModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::SensorDataModel::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard15SensorDataModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::SensorDataModel",
        "QML.Element",
        "auto",
        "sensorsChanged",
        "",
        "sensorMetaDataChanged",
        "enabledChanged",
        "sensorColorsChanged",
        "sensorLabelsChanged",
        "updateRateLimitChanged",
        "readyChanged",
        "addSensor",
        "sensorId",
        "removeSensor",
        "column",
        "sensors",
        "minimum",
        "maximum",
        "enabled",
        "ready",
        "sensorColors",
        "QVariantMap",
        "sensorLabels",
        "updateRateLimit",
        "AdditionalRoles",
        "SensorId",
        "Name",
        "ShortName",
        "Description",
        "Unit",
        "Minimum",
        "Maximum",
        "Type",
        "Value",
        "FormattedValue",
        "Color",
        "UpdateInterval"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sensorsChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sensorMetaDataChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sensorColorsChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sensorLabelsChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateRateLimitChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readyChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'addSensor'
        QtMocHelpers::MethodData<void(const QString &)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'removeSensor'
        QtMocHelpers::MethodData<void(const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'column'
        QtMocHelpers::MethodData<int(const QString &) const>(14, 4, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::QString, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sensors'
        QtMocHelpers::PropertyData<QStringList>(15, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'minimum'
        QtMocHelpers::PropertyData<qreal>(16, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'maximum'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags, 1),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'ready'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags, 6),
        // property 'sensorColors'
        QtMocHelpers::PropertyData<QVariantMap>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'sensorLabels'
        QtMocHelpers::PropertyData<QVariantMap>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'updateRateLimit'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 5),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'AdditionalRoles'
        QtMocHelpers::EnumData<enum AdditionalRoles>(24, 24, QMC::EnumFlags{}).add({
            {   25, AdditionalRoles::SensorId },
            {   26, AdditionalRoles::Name },
            {   27, AdditionalRoles::ShortName },
            {   28, AdditionalRoles::Description },
            {   29, AdditionalRoles::Unit },
            {   30, AdditionalRoles::Minimum },
            {   31, AdditionalRoles::Maximum },
            {   32, AdditionalRoles::Type },
            {   33, AdditionalRoles::Value },
            {   34, AdditionalRoles::FormattedValue },
            {   35, AdditionalRoles::Color },
            {   36, AdditionalRoles::UpdateInterval },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<SensorDataModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KSysGuard::SensorDataModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractTableModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard15SensorDataModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard15SensorDataModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KSysGuard15SensorDataModelE_t>.metaTypes,
    nullptr
} };

void KSysGuard::SensorDataModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SensorDataModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sensorsChanged(); break;
        case 1: _t->sensorMetaDataChanged(); break;
        case 2: _t->enabledChanged(); break;
        case 3: _t->sensorColorsChanged(); break;
        case 4: _t->sensorLabelsChanged(); break;
        case 5: _t->updateRateLimitChanged(); break;
        case 6: _t->readyChanged(); break;
        case 7: _t->addSensor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->removeSensor((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: { int _r = _t->column((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SensorDataModel::*)() const>(_a, &SensorDataModel::sensorsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorDataModel::*)()>(_a, &SensorDataModel::sensorMetaDataChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorDataModel::*)()>(_a, &SensorDataModel::enabledChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorDataModel::*)()>(_a, &SensorDataModel::sensorColorsChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorDataModel::*)()>(_a, &SensorDataModel::sensorLabelsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorDataModel::*)()>(_a, &SensorDataModel::updateRateLimitChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (SensorDataModel::*)()>(_a, &SensorDataModel::readyChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QStringList*>(_v) = _t->sensors(); break;
        case 1: *reinterpret_cast<qreal*>(_v) = _t->minimum(); break;
        case 2: *reinterpret_cast<qreal*>(_v) = _t->maximum(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->isReady(); break;
        case 5: *reinterpret_cast<QVariantMap*>(_v) = _t->sensorColors(); break;
        case 6: *reinterpret_cast<QVariantMap*>(_v) = _t->sensorLabels(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->updateRateLimit(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSensors(*reinterpret_cast<QStringList*>(_v)); break;
        case 3: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 5: _t->setSensorColors(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 6: _t->setSensorLabels(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 7: _t->setUpdateRateLimit(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 7: _t->resetUpdateRateLimit(); break;
        default: break;
        }
    }
}

const QMetaObject *KSysGuard::SensorDataModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSysGuard::SensorDataModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard15SensorDataModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QAbstractTableModel::qt_metacast(_clname);
}

int KSysGuard::SensorDataModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractTableModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void KSysGuard::SensorDataModel::sensorsChanged()const
{
    QMetaObject::activate(const_cast< KSysGuard::SensorDataModel *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSysGuard::SensorDataModel::sensorMetaDataChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KSysGuard::SensorDataModel::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSysGuard::SensorDataModel::sensorColorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KSysGuard::SensorDataModel::sensorLabelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KSysGuard::SensorDataModel::updateRateLimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KSysGuard::SensorDataModel::readyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
