/****************************************************************************
** Meta object code from reading C++ file 'process_controller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksysguard-6.7.4/processcore/process_controller.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'process_controller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KSysGuard17ProcessControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::ProcessController::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard17ProcessControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::ProcessController",
        "QML.Element",
        "auto",
        "sendSignal",
        "Result",
        "",
        "QList<int>",
        "pids",
        "signal",
        "QList<qlonglong>",
        "QVariantList",
        "setPriority",
        "priority",
        "pid",
        "QJSValue",
        "setCpuScheduler",
        "Scheduler",
        "scheduler",
        "cpuScheduler",
        "setIoScheduler",
        "IoPriority",
        "priorityClass",
        "ioPriority",
        "ioScheduler",
        "resultToString",
        "result",
        "window",
        "QWindow*"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'sendSignal'
        QtMocHelpers::MethodData<Result(const QList<int> &, int)>(3, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Int, 8 },
        }}),
        // Method 'sendSignal'
        QtMocHelpers::MethodData<Result(const QList<long long> &, int)>(3, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 9, 7 }, { QMetaType::Int, 8 },
        }}),
        // Method 'sendSignal'
        QtMocHelpers::MethodData<Result(const QVariantList &, int)>(3, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 10, 7 }, { QMetaType::Int, 8 },
        }}),
        // Method 'setPriority'
        QtMocHelpers::MethodData<Result(const QList<int> &, int)>(11, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Int, 12 },
        }}),
        // Method 'setPriority'
        QtMocHelpers::MethodData<Result(const QList<long long> &, int)>(11, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 9, 7 }, { QMetaType::Int, 12 },
        }}),
        // Method 'setPriority'
        QtMocHelpers::MethodData<Result(const QVariantList &, int)>(11, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 10, 7 }, { QMetaType::Int, 12 },
        }}),
        // Method 'priority'
        QtMocHelpers::MethodData<int(long long)>(12, 5, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::LongLong, 13 },
        }}),
        // Method 'priority'
        QtMocHelpers::MethodData<QJSValue(const QList<long long> &)>(12, 5, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 9, 7 },
        }}),
        // Method 'setCpuScheduler'
        QtMocHelpers::MethodData<Result(const QList<int> &, Scheduler, int)>(15, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 16, 17 }, { QMetaType::Int, 12 },
        }}),
        // Method 'setCpuScheduler'
        QtMocHelpers::MethodData<Result(const QList<long long> &, Scheduler, int)>(15, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 9, 7 }, { 0x80000000 | 16, 17 }, { QMetaType::Int, 12 },
        }}),
        // Method 'setCpuScheduler'
        QtMocHelpers::MethodData<Result(const QVariantList &, Scheduler, int)>(15, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 10, 7 }, { 0x80000000 | 16, 17 }, { QMetaType::Int, 12 },
        }}),
        // Method 'cpuScheduler'
        QtMocHelpers::MethodData<Scheduler(long long)>(18, 5, QMC::AccessPublic, 0x80000000 | 16, {{
            { QMetaType::LongLong, 13 },
        }}),
        // Method 'cpuScheduler'
        QtMocHelpers::MethodData<QJSValue(const QList<long long> &)>(18, 5, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 9, 7 },
        }}),
        // Method 'setIoScheduler'
        QtMocHelpers::MethodData<Result(const QList<int> &, IoPriority, int)>(19, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 6, 7 }, { 0x80000000 | 20, 21 }, { QMetaType::Int, 12 },
        }}),
        // Method 'setIoScheduler'
        QtMocHelpers::MethodData<Result(const QList<long long> &, IoPriority, int)>(19, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 9, 7 }, { 0x80000000 | 20, 21 }, { QMetaType::Int, 12 },
        }}),
        // Method 'setIoScheduler'
        QtMocHelpers::MethodData<Result(const QVariantList &, IoPriority, int)>(19, 5, QMC::AccessPublic, 0x80000000 | 4, {{
            { 0x80000000 | 10, 7 }, { 0x80000000 | 20, 21 }, { QMetaType::Int, 12 },
        }}),
        // Method 'ioPriority'
        QtMocHelpers::MethodData<int(long long)>(22, 5, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::LongLong, 13 },
        }}),
        // Method 'ioPriority'
        QtMocHelpers::MethodData<QJSValue(const QList<long long> &)>(22, 5, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 9, 7 },
        }}),
        // Method 'ioScheduler'
        QtMocHelpers::MethodData<IoPriority(long long)>(23, 5, QMC::AccessPublic, 0x80000000 | 20, {{
            { QMetaType::LongLong, 13 },
        }}),
        // Method 'ioScheduler'
        QtMocHelpers::MethodData<QJSValue(const QList<long long> &)>(23, 5, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 9, 7 },
        }}),
        // Method 'resultToString'
        QtMocHelpers::MethodData<QString(Result)>(24, 5, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 4, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'window'
        QtMocHelpers::PropertyData<QWindow*>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<ProcessController, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KSysGuard::ProcessController::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard17ProcessControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard17ProcessControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KSysGuard17ProcessControllerE_t>.metaTypes,
    nullptr
} };

void KSysGuard::ProcessController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProcessController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { Result _r = _t->sendSignal((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 1: { Result _r = _t->sendSignal((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 2: { Result _r = _t->sendSignal((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 3: { Result _r = _t->setPriority((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 4: { Result _r = _t->setPriority((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 5: { Result _r = _t->setPriority((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 6: { int _r = _t->priority((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 7: { QJSValue _r = _t->priority((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 8: { Result _r = _t->setCpuScheduler((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Scheduler>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 9: { Result _r = _t->setCpuScheduler((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Scheduler>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 10: { Result _r = _t->setCpuScheduler((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Scheduler>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 11: { Scheduler _r = _t->cpuScheduler((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<Scheduler*>(_a[0]) = std::move(_r); }  break;
        case 12: { QJSValue _r = _t->cpuScheduler((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 13: { Result _r = _t->setIoScheduler((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<IoPriority>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 14: { Result _r = _t->setIoScheduler((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<IoPriority>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 15: { Result _r = _t->setIoScheduler((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<IoPriority>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<Result*>(_a[0]) = std::move(_r); }  break;
        case 16: { int _r = _t->ioPriority((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 17: { QJSValue _r = _t->ioPriority((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 18: { IoPriority _r = _t->ioScheduler((*reinterpret_cast<std::add_pointer_t<qlonglong>>(_a[1])));
            if (_a[0]) *reinterpret_cast<IoPriority*>(_a[0]) = std::move(_r); }  break;
        case 19: { QJSValue _r = _t->ioScheduler((*reinterpret_cast<std::add_pointer_t<QList<qlonglong>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QJSValue*>(_a[0]) = std::move(_r); }  break;
        case 20: { QString _r = _t->resultToString((*reinterpret_cast<std::add_pointer_t<Result>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 9:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<qlonglong> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QWindow**>(_v) = _t->window(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setWindow(*reinterpret_cast<QWindow**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KSysGuard::ProcessController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSysGuard::ProcessController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard17ProcessControllerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KSysGuard::ProcessController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
