/****************************************************************************
** Meta object code from reading C++ file 'process_foreign_types.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksysguard-6.7.4/processcore/process_foreign_types.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'process_foreign_types.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KSysGuardProcessE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuardProcess::qt_create_metaobjectdata<qt_meta_tag_ZN16KSysGuardProcessE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuardProcess",
        "QML.Element",
        "Process",
        "ProcessStatus",
        "Running",
        "Sleeping",
        "DiskSleep",
        "Zombie",
        "Stopped",
        "Paging",
        "Ended",
        "OtherStatus",
        "IoPriorityClass",
        "None",
        "RealTime",
        "BestEffort",
        "Idle",
        "Scheduler",
        "Other",
        "Fifo",
        "RoundRobin",
        "Batch",
        "SchedulerIdle",
        "Interactive"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ProcessStatus'
        QtMocHelpers::EnumData<ProcessStatus>(3, 3, QMC::EnumFlags{}).add({
            {    4, ProcessStatus::Running },
            {    5, ProcessStatus::Sleeping },
            {    6, ProcessStatus::DiskSleep },
            {    7, ProcessStatus::Zombie },
            {    8, ProcessStatus::Stopped },
            {    9, ProcessStatus::Paging },
            {   10, ProcessStatus::Ended },
            {   11, ProcessStatus::OtherStatus },
        }),
        // enum 'IoPriorityClass'
        QtMocHelpers::EnumData<IoPriorityClass>(12, 12, QMC::EnumFlags{}).add({
            {   13, IoPriorityClass::None },
            {   14, IoPriorityClass::RealTime },
            {   15, IoPriorityClass::BestEffort },
            {   16, IoPriorityClass::Idle },
        }),
        // enum 'Scheduler'
        QtMocHelpers::EnumData<Scheduler>(17, 17, QMC::EnumFlags{}).add({
            {   18, Scheduler::Other },
            {   19, Scheduler::Fifo },
            {   20, Scheduler::RoundRobin },
            {   21, Scheduler::Batch },
            {   22, Scheduler::SchedulerIdle },
            {   23, Scheduler::Interactive },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN16KSysGuardProcessE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN16KSysGuardProcessE =
    KSysGuardProcess::qt_create_metaobjectdata<qt_meta_tag_ZN16KSysGuardProcessE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN16KSysGuardProcessE =
    qt_staticMetaObjectContent_ZN16KSysGuardProcessE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN16KSysGuardProcessE =
    qt_staticMetaObjectContent_ZN16KSysGuardProcessE.relocatingData;

Q_CONSTINIT const QMetaObject KSysGuardProcess::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN16KSysGuardProcessE.stringdata,
    qt_staticMetaObjectStaticContent_ZN16KSysGuardProcessE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN16KSysGuardProcessE.metaTypes,
    nullptr
} };

QT_WARNING_POP
