/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<application_data_model.h>)
#  include <application_data_model.h>
#endif
#if __has_include(<enums.h>)
#  include <enums.h>
#endif
#if __has_include(<process_attribute_model.h>)
#  include <process_attribute_model.h>
#endif
#if __has_include(<process_controller.h>)
#  include <process_controller.h>
#endif
#if __has_include(<process_data_model.h>)
#  include <process_data_model.h>
#endif
#if __has_include(<process_foreign_types.h>)
#  include <process_foreign_types.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_ksysguard_process()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<KSysGuard::ApplicationDataModel>("org.kde.ksysguard.process", 1);
    QMetaType::fromType<KSysGuard::CGroupDataModel *>().id();
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KSysGuard::Enums::IoPriority::staticMetaObject;},
            "KSysGuard::Enums::IoPriority");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KSysGuard::Enums::IoPriority::staticMetaObject, "org.kde.ksysguard.process", 1, nullptr, &KSysGuard::Enums::IoPriority::staticMetaObject, nullptr);
    qmlRegisterEnum<KSysGuard::Enums::IoPriority::IoPriority>("KSysGuard::Enums::IoPriority::IoPriority");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KSysGuard::Enums::ProcessStatus::staticMetaObject;},
            "KSysGuard::Enums::ProcessStatus");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KSysGuard::Enums::ProcessStatus::staticMetaObject, "org.kde.ksysguard.process", 1, nullptr, &KSysGuard::Enums::ProcessStatus::staticMetaObject, nullptr);
    qmlRegisterEnum<KSysGuard::Enums::ProcessStatus::ProcessStatus>("KSysGuard::Enums::ProcessStatus::ProcessStatus");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KSysGuard::Enums::Result::staticMetaObject;},
            "KSysGuard::Enums::Result");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KSysGuard::Enums::Result::staticMetaObject, "org.kde.ksysguard.process", 1, nullptr, &KSysGuard::Enums::Result::staticMetaObject, nullptr);
    qmlRegisterEnum<KSysGuard::Enums::Result::Result>("KSysGuard::Enums::Result::Result");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KSysGuard::Enums::Scheduler::staticMetaObject;},
            "KSysGuard::Enums::Scheduler");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KSysGuard::Enums::Scheduler::staticMetaObject, "org.kde.ksysguard.process", 1, nullptr, &KSysGuard::Enums::Scheduler::staticMetaObject, nullptr);
    qmlRegisterEnum<KSysGuard::Enums::Scheduler::Scheduler>("KSysGuard::Enums::Scheduler::Scheduler");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KSysGuard::Enums::Signal::staticMetaObject;},
            "KSysGuard::Enums::Signal");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KSysGuard::Enums::Signal::staticMetaObject, "org.kde.ksysguard.process", 1, nullptr, &KSysGuard::Enums::Signal::staticMetaObject, nullptr);
    qmlRegisterEnum<KSysGuard::Enums::Signal::Signal>("KSysGuard::Enums::Signal::Signal");
    qmlRegisterTypesAndRevisions<KSysGuard::ProcessAttributeModel>("org.kde.ksysguard.process", 1);
    qmlRegisterEnum<KSysGuard::ProcessAttributeModel::Role>("KSysGuard::ProcessAttributeModel::Role");
    qmlRegisterTypesAndRevisions<KSysGuard::ProcessController>("org.kde.ksysguard.process", 1);
    qmlRegisterTypesAndRevisions<KSysGuard::ProcessDataModel>("org.kde.ksysguard.process", 1);
    qmlRegisterEnum<KSysGuard::ProcessDataModel::AdditionalRoles>("KSysGuard::ProcessDataModel::AdditionalRoles");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KSysGuardProcess::staticMetaObject;},
            "KSysGuardProcess");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KSysGuardProcess::staticMetaObject, "org.kde.ksysguard.process", 1, nullptr, &KSysGuardProcess::staticMetaObject, nullptr);
    qmlRegisterEnum<KSysGuardProcess::ProcessStatus>("KSysGuardProcess::ProcessStatus");
    qmlRegisterEnum<KSysGuardProcess::IoPriorityClass>("KSysGuardProcess::IoPriorityClass");
    qmlRegisterEnum<KSysGuardProcess::Scheduler>("KSysGuardProcess::Scheduler");
    QMetaType::fromType<QAbstractItemModel *>().id();
    qmlRegisterEnum<QAbstractItemModel::LayoutChangeHint>("QAbstractItemModel::LayoutChangeHint");
    qmlRegisterEnum<QAbstractItemModel::CheckIndexOption>("QAbstractItemModel::CheckIndexOption");
    QMetaType::fromType<QAbstractListModel *>().id();
    QT_WARNING_POP
    qmlRegisterModule("org.kde.ksysguard.process", 1, 0);
}

static const QQmlModuleRegistration orgkdeksysguardprocessRegistration("org.kde.ksysguard.process", qml_register_types_org_kde_ksysguard_process);
