/****************************************************************************
** Meta object code from reading C++ file 'ksysguarddaemon.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "ksysguarddaemon.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksysguarddaemon.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN30OrgKdeKSysGuardDaemonInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto OrgKdeKSysGuardDaemonInterface::qt_create_metaobjectdata<qt_meta_tag_ZN30OrgKdeKSysGuardDaemonInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "OrgKdeKSysGuardDaemonInterface",
        "newSensorData",
        "",
        "KSysGuard::SensorDataList",
        "sensorData",
        "sensorAdded",
        "sensorId",
        "sensorMetaDataChanged",
        "QHash<QString,KSysGuard::SensorInfo>",
        "metaData",
        "sensorRemoved",
        "allSensors",
        "QDBusPendingReply<QHash<QString,KSysGuard::SensorInfo>>",
        "QDBusPendingReply<KSysGuard::SensorDataList>",
        "sensorIds",
        "sensors",
        "sensorsIds",
        "subscribe",
        "QDBusPendingReply<>",
        "unsubscribe"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'newSensorData'
        QtMocHelpers::SignalData<void(KSysGuard::SensorDataList)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'sensorAdded'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'sensorMetaDataChanged'
        QtMocHelpers::SignalData<void(const QHash<QString,KSysGuard::SensorInfo> &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'sensorRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Slot 'allSensors'
        QtMocHelpers::SlotData<QDBusPendingReply<QHash<QString,KSysGuard::SensorInfo> >()>(11, 2, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'sensorData'
        QtMocHelpers::SlotData<QDBusPendingReply<KSysGuard::SensorDataList>(const QStringList &)>(4, 2, QMC::AccessPublic, 0x80000000 | 13, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Slot 'sensors'
        QtMocHelpers::SlotData<QDBusPendingReply<QHash<QString,KSysGuard::SensorInfo> >(const QStringList &)>(15, 2, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QStringList, 16 },
        }}),
        // Slot 'subscribe'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(17, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QStringList, 14 },
        }}),
        // Slot 'unsubscribe'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QStringList &)>(19, 2, QMC::AccessPublic, 0x80000000 | 18, {{
            { QMetaType::QStringList, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<OrgKdeKSysGuardDaemonInterface, qt_meta_tag_ZN30OrgKdeKSysGuardDaemonInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject OrgKdeKSysGuardDaemonInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30OrgKdeKSysGuardDaemonInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30OrgKdeKSysGuardDaemonInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN30OrgKdeKSysGuardDaemonInterfaceE_t>.metaTypes,
    nullptr
} };

void OrgKdeKSysGuardDaemonInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<OrgKdeKSysGuardDaemonInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newSensorData((*reinterpret_cast<std::add_pointer_t<KSysGuard::SensorDataList>>(_a[1]))); break;
        case 1: _t->sensorAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->sensorMetaDataChanged((*reinterpret_cast<std::add_pointer_t<QHash<QString,KSysGuard::SensorInfo>>>(_a[1]))); break;
        case 3: _t->sensorRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: { QDBusPendingReply<QHash<QString,KSysGuard::SensorInfo>> _r = _t->allSensors();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QHash<QString,KSysGuard::SensorInfo>>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<KSysGuard::SensorDataList> _r = _t->sensorData((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<KSysGuard::SensorDataList>*>(_a[0]) = std::move(_r); }  break;
        case 6: { QDBusPendingReply<QHash<QString,KSysGuard::SensorInfo>> _r = _t->sensors((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QHash<QString,KSysGuard::SensorInfo>>*>(_a[0]) = std::move(_r); }  break;
        case 7: { QDBusPendingReply<> _r = _t->subscribe((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 8: { QDBusPendingReply<> _r = _t->unsubscribe((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KSysGuard::SensorDataList >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKSysGuardDaemonInterface::*)(KSysGuard::SensorDataList )>(_a, &OrgKdeKSysGuardDaemonInterface::newSensorData, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKSysGuardDaemonInterface::*)(const QString & )>(_a, &OrgKdeKSysGuardDaemonInterface::sensorAdded, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKSysGuardDaemonInterface::*)(const QHash<QString,KSysGuard::SensorInfo> & )>(_a, &OrgKdeKSysGuardDaemonInterface::sensorMetaDataChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (OrgKdeKSysGuardDaemonInterface::*)(const QString & )>(_a, &OrgKdeKSysGuardDaemonInterface::sensorRemoved, 3))
            return;
    }
}

const QMetaObject *OrgKdeKSysGuardDaemonInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *OrgKdeKSysGuardDaemonInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN30OrgKdeKSysGuardDaemonInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int OrgKdeKSysGuardDaemonInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void OrgKdeKSysGuardDaemonInterface::newSensorData(KSysGuard::SensorDataList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void OrgKdeKSysGuardDaemonInterface::sensorAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void OrgKdeKSysGuardDaemonInterface::sensorMetaDataChanged(const QHash<QString,KSysGuard::SensorInfo> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void OrgKdeKSysGuardDaemonInterface::sensorRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
