// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "networklogging.h"


Q_LOGGING_CATEGORY(KSYSGUARD_PLUGIN_NETWORK, "org.kde.ksysguard.plugin.network", QtInfoMsg)

