// This file was generated by ecm_qt_declare_logging_category(): DO NOT EDIT!

#include "processcore_debug.h"


Q_LOGGING_CATEGORY(LIBKSYSGUARD_PROCESSCORE, "org.kde.libksysguard.processcore", QtInfoMsg)

