/****************************************************************************
** Meta object code from reading C++ file 'Sensor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksysguard-6.7.4/sensors/Sensor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Sensor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KSysGuard6SensorE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::Sensor::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard6SensorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::Sensor",
        "QML.Element",
        "auto",
        "sensorIdChanged",
        "",
        "statusChanged",
        "metaDataChanged",
        "valueChanged",
        "enabledChanged",
        "updateIntervalChanged",
        "updateRateLimitChanged",
        "sensorId",
        "name",
        "shortName",
        "description",
        "unit",
        "KSysGuard::Unit",
        "minimum",
        "maximum",
        "type",
        "QVariant::Type",
        "status",
        "Status",
        "value",
        "QVariant",
        "formattedValue",
        "enabled",
        "updateInterval",
        "updateRateLimit",
        "Unknown",
        "Loading",
        "Ready",
        "Error",
        "Removed"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'sensorIdChanged'
        QtMocHelpers::SignalData<void() const>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'statusChanged'
        QtMocHelpers::SignalData<void() const>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'metaDataChanged'
        QtMocHelpers::SignalData<void() const>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void() const>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateIntervalChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateRateLimitChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sensorId'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(12, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'shortName'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'description'
        QtMocHelpers::PropertyData<QString>(14, QMetaType::QString, QMC::DefaultPropertyFlags, 2),
        // property 'unit'
        QtMocHelpers::PropertyData<KSysGuard::Unit>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'minimum'
        QtMocHelpers::PropertyData<qreal>(17, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'maximum'
        QtMocHelpers::PropertyData<qreal>(18, QMetaType::QReal, QMC::DefaultPropertyFlags, 2),
        // property 'type'
        QtMocHelpers::PropertyData<QVariant::Type>(19, 0x80000000 | 20, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'status'
        QtMocHelpers::PropertyData<enum Status>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 1),
        // property 'value'
        QtMocHelpers::PropertyData<QVariant>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 3),
        // property 'formattedValue'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'enabled'
        QtMocHelpers::PropertyData<bool>(26, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'updateInterval'
        QtMocHelpers::PropertyData<uint>(27, QMetaType::UInt, QMC::DefaultPropertyFlags, 5),
        // property 'updateRateLimit'
        QtMocHelpers::PropertyData<int>(28, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Status'
        QtMocHelpers::EnumData<enum Status>(22, 22, QMC::EnumIsScoped).add({
            {   29, Status::Unknown },
            {   30, Status::Loading },
            {   31, Status::Ready },
            {   32, Status::Error },
            {   33, Status::Removed },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<Sensor, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN9KSysGuard6SensorE[] = {
    QMetaObject::SuperData::link<KSysGuard::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject KSysGuard::Sensor::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard6SensorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard6SensorE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN9KSysGuard6SensorE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KSysGuard6SensorE_t>.metaTypes,
    nullptr
} };

void KSysGuard::Sensor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Sensor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->sensorIdChanged(); break;
        case 1: _t->statusChanged(); break;
        case 2: _t->metaDataChanged(); break;
        case 3: _t->valueChanged(); break;
        case 4: _t->enabledChanged(); break;
        case 5: _t->updateIntervalChanged(); break;
        case 6: _t->updateRateLimitChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Sensor::*)() const>(_a, &Sensor::sensorIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sensor::*)() const>(_a, &Sensor::statusChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sensor::*)() const>(_a, &Sensor::metaDataChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sensor::*)() const>(_a, &Sensor::valueChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sensor::*)()>(_a, &Sensor::enabledChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sensor::*)()>(_a, &Sensor::updateIntervalChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Sensor::*)()>(_a, &Sensor::updateRateLimitChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->sensorId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->shortName(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->description(); break;
        case 4: *reinterpret_cast<KSysGuard::Unit*>(_v) = _t->unit(); break;
        case 5: *reinterpret_cast<qreal*>(_v) = _t->minimum(); break;
        case 6: *reinterpret_cast<qreal*>(_v) = _t->maximum(); break;
        case 7: *reinterpret_cast<QVariant::Type*>(_v) = _t->type(); break;
        case 8: *reinterpret_cast<enum Status*>(_v) = _t->status(); break;
        case 9: *reinterpret_cast<QVariant*>(_v) = _t->value(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->formattedValue(); break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->enabled(); break;
        case 12: *reinterpret_cast<uint*>(_v) = _t->updateInterval(); break;
        case 13: *reinterpret_cast<int*>(_v) = _t->updateRateLimit(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setSensorId(*reinterpret_cast<QString*>(_v)); break;
        case 11: _t->setEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 13: _t->setUpdateRateLimit(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 13: _t->resetUpdateRateLimit(); break;
        default: break;
        }
    }
}

const QMetaObject *KSysGuard::Sensor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSysGuard::Sensor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard6SensorE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int KSysGuard::Sensor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void KSysGuard::Sensor::sensorIdChanged()const
{
    QMetaObject::activate(const_cast< KSysGuard::Sensor *>(this), &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSysGuard::Sensor::statusChanged()const
{
    QMetaObject::activate(const_cast< KSysGuard::Sensor *>(this), &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KSysGuard::Sensor::metaDataChanged()const
{
    QMetaObject::activate(const_cast< KSysGuard::Sensor *>(this), &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSysGuard::Sensor::valueChanged()const
{
    QMetaObject::activate(const_cast< KSysGuard::Sensor *>(this), &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KSysGuard::Sensor::enabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KSysGuard::Sensor::updateIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KSysGuard::Sensor::updateRateLimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
