/****************************************************************************
** Meta object code from reading C++ file 'FaceLoader.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksysguard-6.7.4/faces/FaceLoader.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'FaceLoader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KSysGuard10FaceLoaderE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::FaceLoader::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard10FaceLoaderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::FaceLoader",
        "QML.Element",
        "auto",
        "parentControllerChanged",
        "",
        "groupNameChanged",
        "sensorsChanged",
        "faceIdChanged",
        "colorsChanged",
        "labelsChanged",
        "updateRateLimitChanged",
        "readOnlyChanged",
        "controllerChanged",
        "reload",
        "parentController",
        "KSysGuard::SensorFaceController*",
        "groupName",
        "sensors",
        "QJsonArray",
        "faceId",
        "colors",
        "QVariantMap",
        "labels",
        "updateRateLimit",
        "readOnly",
        "controller"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'parentControllerChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'groupNameChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sensorsChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'faceIdChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorsChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'labelsChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateRateLimitChanged'
        QtMocHelpers::SignalData<void()>(10, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'readOnlyChanged'
        QtMocHelpers::SignalData<void()>(11, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'controllerChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'reload'
        QtMocHelpers::MethodData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'parentController'
        QtMocHelpers::PropertyData<KSysGuard::SensorFaceController*>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'groupName'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'sensors'
        QtMocHelpers::PropertyData<QJsonArray>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'faceId'
        QtMocHelpers::PropertyData<QString>(19, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'colors'
        QtMocHelpers::PropertyData<QVariantMap>(20, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'labels'
        QtMocHelpers::PropertyData<QVariantMap>(22, 0x80000000 | 21, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 5),
        // property 'updateRateLimit'
        QtMocHelpers::PropertyData<int>(23, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'readOnly'
        QtMocHelpers::PropertyData<bool>(24, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'controller'
        QtMocHelpers::PropertyData<KSysGuard::SensorFaceController*>(25, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<FaceLoader, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KSysGuard::FaceLoader::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard10FaceLoaderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard10FaceLoaderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KSysGuard10FaceLoaderE_t>.metaTypes,
    nullptr
} };

void KSysGuard::FaceLoader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FaceLoader *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->parentControllerChanged(); break;
        case 1: _t->groupNameChanged(); break;
        case 2: _t->sensorsChanged(); break;
        case 3: _t->faceIdChanged(); break;
        case 4: _t->colorsChanged(); break;
        case 5: _t->labelsChanged(); break;
        case 6: _t->updateRateLimitChanged(); break;
        case 7: _t->readOnlyChanged(); break;
        case 8: _t->controllerChanged(); break;
        case 9: _t->reload(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FaceLoader::*)()>(_a, &FaceLoader::parentControllerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FaceLoader::*)()>(_a, &FaceLoader::groupNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (FaceLoader::*)()>(_a, &FaceLoader::sensorsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (FaceLoader::*)()>(_a, &FaceLoader::faceIdChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (FaceLoader::*)()>(_a, &FaceLoader::colorsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (FaceLoader::*)()>(_a, &FaceLoader::labelsChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (FaceLoader::*)()>(_a, &FaceLoader::updateRateLimitChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (FaceLoader::*)()>(_a, &FaceLoader::readOnlyChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (FaceLoader::*)()>(_a, &FaceLoader::controllerChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 8:
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KSysGuard::SensorFaceController* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<KSysGuard::SensorFaceController**>(_v) = _t->parentController(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->groupName(); break;
        case 2: *reinterpret_cast<QJsonArray*>(_v) = _t->sensors(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->faceId(); break;
        case 4: *reinterpret_cast<QVariantMap*>(_v) = _t->colors(); break;
        case 5: *reinterpret_cast<QVariantMap*>(_v) = _t->labels(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->updateRateLimit(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->readOnly(); break;
        case 8: *reinterpret_cast<KSysGuard::SensorFaceController**>(_v) = _t->controller(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setParentController(*reinterpret_cast<KSysGuard::SensorFaceController**>(_v)); break;
        case 1: _t->setGroupName(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setSensors(*reinterpret_cast<QJsonArray*>(_v)); break;
        case 3: _t->setFaceId(*reinterpret_cast<QString*>(_v)); break;
        case 4: _t->setColors(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 5: _t->setLabels(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 6: _t->setUpdateRateLimit(*reinterpret_cast<int*>(_v)); break;
        case 7: _t->setReadOnly(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KSysGuard::FaceLoader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSysGuard::FaceLoader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard10FaceLoaderE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QObject::qt_metacast(_clname);
}

int KSysGuard::FaceLoader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KSysGuard::FaceLoader::parentControllerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSysGuard::FaceLoader::groupNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KSysGuard::FaceLoader::sensorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSysGuard::FaceLoader::faceIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KSysGuard::FaceLoader::colorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KSysGuard::FaceLoader::labelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KSysGuard::FaceLoader::updateRateLimitChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KSysGuard::FaceLoader::readOnlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KSysGuard::FaceLoader::controllerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
