/****************************************************************************
** Meta object code from reading C++ file 'processes.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksysguard-6.7.4/processcore/processes.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'processes.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KSysGuard9ProcessesE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::Processes::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard9ProcessesE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::Processes",
        "processChanged",
        "",
        "KSysGuard::Process*",
        "process",
        "onlyTotalCpu",
        "beginAddProcess",
        "endAddProcess",
        "beginRemoveProcess",
        "endRemoveProcess",
        "beginMoveProcess",
        "new_parent",
        "endMoveProcess",
        "updated",
        "processesUpdated",
        "processUpdated",
        "pid",
        "Process::Updates",
        "changes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'processChanged'
        QtMocHelpers::SignalData<void(KSysGuard::Process *, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'beginAddProcess'
        QtMocHelpers::SignalData<void(KSysGuard::Process *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'endAddProcess'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'beginRemoveProcess'
        QtMocHelpers::SignalData<void(KSysGuard::Process *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'endRemoveProcess'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'beginMoveProcess'
        QtMocHelpers::SignalData<void(KSysGuard::Process *, KSysGuard::Process *)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 11 },
        }}),
        // Signal 'endMoveProcess'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updated'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processesUpdated'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processUpdated'
        QtMocHelpers::SlotData<void(long, const Process::Updates &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Long, 16 }, { 0x80000000 | 17, 18 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Processes, qt_meta_tag_ZN9KSysGuard9ProcessesE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KSysGuard::Processes::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard9ProcessesE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard9ProcessesE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KSysGuard9ProcessesE_t>.metaTypes,
    nullptr
} };

void KSysGuard::Processes::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Processes *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->processChanged((*reinterpret_cast<std::add_pointer_t<KSysGuard::Process*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->beginAddProcess((*reinterpret_cast<std::add_pointer_t<KSysGuard::Process*>>(_a[1]))); break;
        case 2: _t->endAddProcess(); break;
        case 3: _t->beginRemoveProcess((*reinterpret_cast<std::add_pointer_t<KSysGuard::Process*>>(_a[1]))); break;
        case 4: _t->endRemoveProcess(); break;
        case 5: _t->beginMoveProcess((*reinterpret_cast<std::add_pointer_t<KSysGuard::Process*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KSysGuard::Process*>>(_a[2]))); break;
        case 6: _t->endMoveProcess(); break;
        case 7: _t->updated(); break;
        case 8: _t->processesUpdated(); break;
        case 9: _t->processUpdated((*reinterpret_cast<std::add_pointer_t<long>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Process::Updates>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Processes::*)(KSysGuard::Process * , bool )>(_a, &Processes::processChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Processes::*)(KSysGuard::Process * )>(_a, &Processes::beginAddProcess, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Processes::*)()>(_a, &Processes::endAddProcess, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Processes::*)(KSysGuard::Process * )>(_a, &Processes::beginRemoveProcess, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Processes::*)()>(_a, &Processes::endRemoveProcess, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Processes::*)(KSysGuard::Process * , KSysGuard::Process * )>(_a, &Processes::beginMoveProcess, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Processes::*)()>(_a, &Processes::endMoveProcess, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Processes::*)()>(_a, &Processes::updated, 7))
            return;
    }
}

const QMetaObject *KSysGuard::Processes::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSysGuard::Processes::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KSysGuard9ProcessesE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KSysGuard::Processes::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void KSysGuard::Processes::processChanged(KSysGuard::Process * _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void KSysGuard::Processes::beginAddProcess(KSysGuard::Process * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KSysGuard::Processes::endAddProcess()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSysGuard::Processes::beginRemoveProcess(KSysGuard::Process * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void KSysGuard::Processes::endRemoveProcess()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KSysGuard::Processes::beginMoveProcess(KSysGuard::Process * _t1, KSysGuard::Process * _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void KSysGuard::Processes::endMoveProcess()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KSysGuard::Processes::updated()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
