/****************************************************************************
** Meta object code from reading C++ file 'enums.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksysguard-6.7.4/processcore/enums.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'enums.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KSysGuard5Enums6ResultE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::Enums::Result::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard5Enums6ResultE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::Enums::Result",
        "QML.Element",
        "auto",
        "Result",
        "Unknown",
        "Success",
        "InsufficientPermissions",
        "NoSuchProcess",
        "Unsupported",
        "UserCancelled",
        "Error"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Result'
        QtMocHelpers::EnumData<Result>(3, 3, QMC::EnumFlags{}).add({
            {    4, Result::Unknown },
            {    5, Result::Success },
            {    6, Result::InsufficientPermissions },
            {    7, Result::NoSuchProcess },
            {    8, Result::Unsupported },
            {    9, Result::UserCancelled },
            {   10, Result::Error },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9KSysGuard5Enums6ResultE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN9KSysGuard5Enums6ResultE =
    KSysGuard::Enums::Result::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard5Enums6ResultE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums6ResultE =
    qt_staticMetaObjectContent_ZN9KSysGuard5Enums6ResultE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9KSysGuard5Enums6ResultE =
    qt_staticMetaObjectContent_ZN9KSysGuard5Enums6ResultE.relocatingData;

Q_CONSTINIT const QMetaObject KSysGuard::Enums::Result::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums6ResultE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums6ResultE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9KSysGuard5Enums6ResultE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN9KSysGuard5Enums6SignalE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::Enums::Signal::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard5Enums6SignalE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::Enums::Signal",
        "QML.Element",
        "auto",
        "Signal",
        "StopSignal",
        "ContinueSignal",
        "HangupSignal",
        "InterruptSignal",
        "TerminateSignal",
        "KillSignal",
        "User1Signal",
        "User2Signal"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Signal'
        QtMocHelpers::EnumData<Signal>(3, 3, QMC::EnumFlags{}).add({
            {    4, Signal::StopSignal },
            {    5, Signal::ContinueSignal },
            {    6, Signal::HangupSignal },
            {    7, Signal::InterruptSignal },
            {    8, Signal::TerminateSignal },
            {    9, Signal::KillSignal },
            {   10, Signal::User1Signal },
            {   11, Signal::User2Signal },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9KSysGuard5Enums6SignalE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN9KSysGuard5Enums6SignalE =
    KSysGuard::Enums::Signal::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard5Enums6SignalE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums6SignalE =
    qt_staticMetaObjectContent_ZN9KSysGuard5Enums6SignalE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9KSysGuard5Enums6SignalE =
    qt_staticMetaObjectContent_ZN9KSysGuard5Enums6SignalE.relocatingData;

Q_CONSTINIT const QMetaObject KSysGuard::Enums::Signal::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums6SignalE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums6SignalE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9KSysGuard5Enums6SignalE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN9KSysGuard5Enums13ProcessStatusE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::Enums::ProcessStatus::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard5Enums13ProcessStatusE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::Enums::ProcessStatus",
        "QML.Element",
        "auto",
        "ProcessStatus",
        "Running",
        "Sleeping",
        "DiskSleep",
        "Zombie",
        "Stopped",
        "Paging",
        "Ended",
        "OtherStatus"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'ProcessStatus'
        QtMocHelpers::EnumData<ProcessStatus>(3, 3, QMC::EnumFlags{}).add({
            {    4, ProcessStatus::Running },
            {    5, ProcessStatus::Sleeping },
            {    6, ProcessStatus::DiskSleep },
            {    7, ProcessStatus::Zombie },
            {    8, ProcessStatus::Stopped },
            {    9, ProcessStatus::Paging },
            {   10, ProcessStatus::Ended },
            {   11, ProcessStatus::OtherStatus },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9KSysGuard5Enums13ProcessStatusE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN9KSysGuard5Enums13ProcessStatusE =
    KSysGuard::Enums::ProcessStatus::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard5Enums13ProcessStatusE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums13ProcessStatusE =
    qt_staticMetaObjectContent_ZN9KSysGuard5Enums13ProcessStatusE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9KSysGuard5Enums13ProcessStatusE =
    qt_staticMetaObjectContent_ZN9KSysGuard5Enums13ProcessStatusE.relocatingData;

Q_CONSTINIT const QMetaObject KSysGuard::Enums::ProcessStatus::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums13ProcessStatusE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums13ProcessStatusE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9KSysGuard5Enums13ProcessStatusE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN9KSysGuard5Enums10IoPriorityE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::Enums::IoPriority::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard5Enums10IoPriorityE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::Enums::IoPriority",
        "QML.Element",
        "auto",
        "IoPriority",
        "None",
        "RealTime",
        "BestEffort",
        "Idle"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'IoPriority'
        QtMocHelpers::EnumData<IoPriority>(3, 3, QMC::EnumFlags{}).add({
            {    4, IoPriority::None },
            {    5, IoPriority::RealTime },
            {    6, IoPriority::BestEffort },
            {    7, IoPriority::Idle },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9KSysGuard5Enums10IoPriorityE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN9KSysGuard5Enums10IoPriorityE =
    KSysGuard::Enums::IoPriority::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard5Enums10IoPriorityE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums10IoPriorityE =
    qt_staticMetaObjectContent_ZN9KSysGuard5Enums10IoPriorityE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9KSysGuard5Enums10IoPriorityE =
    qt_staticMetaObjectContent_ZN9KSysGuard5Enums10IoPriorityE.relocatingData;

Q_CONSTINIT const QMetaObject KSysGuard::Enums::IoPriority::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums10IoPriorityE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums10IoPriorityE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9KSysGuard5Enums10IoPriorityE.metaTypes,
    nullptr
} };

namespace {
struct qt_meta_tag_ZN9KSysGuard5Enums9SchedulerE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::Enums::Scheduler::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard5Enums9SchedulerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard::Enums::Scheduler",
        "QML.Element",
        "auto",
        "Scheduler",
        "Other",
        "Fifo",
        "RoundRobin",
        "Batch",
        "SchedulerIdle",
        "Interactive"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Scheduler'
        QtMocHelpers::EnumData<Scheduler>(3, 3, QMC::EnumFlags{}).add({
            {    4, Scheduler::Other },
            {    5, Scheduler::Fifo },
            {    6, Scheduler::RoundRobin },
            {    7, Scheduler::Batch },
            {    8, Scheduler::SchedulerIdle },
            {    9, Scheduler::Interactive },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9KSysGuard5Enums9SchedulerE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN9KSysGuard5Enums9SchedulerE =
    KSysGuard::Enums::Scheduler::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuard5Enums9SchedulerE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums9SchedulerE =
    qt_staticMetaObjectContent_ZN9KSysGuard5Enums9SchedulerE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9KSysGuard5Enums9SchedulerE =
    qt_staticMetaObjectContent_ZN9KSysGuard5Enums9SchedulerE.relocatingData;

Q_CONSTINIT const QMetaObject KSysGuard::Enums::Scheduler::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums9SchedulerE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9KSysGuard5Enums9SchedulerE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9KSysGuard5Enums9SchedulerE.metaTypes,
    nullptr
} };

QT_WARNING_POP
