/****************************************************************************
** Meta object code from reading C++ file 'Unit.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../libksysguard-6.7.4/formatter/Unit.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'Unit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KSysGuardE_t {};
} // unnamed namespace

template <> constexpr inline auto KSysGuard::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuardE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSysGuard",
        "QML.Element",
        "Units",
        "MetricPrefix",
        "MetricPrefixAutoAdjust",
        "MetricPrefixUnity",
        "MetricPrefixKilo",
        "MetricPrefixMega",
        "MetricPrefixGiga",
        "MetricPrefixTera",
        "MetricPrefixPeta",
        "MetricPrefixLast",
        "Unit",
        "UnitInvalid",
        "UnitNone",
        "UnitByte",
        "UnitKiloByte",
        "UnitMegaByte",
        "UnitGigaByte",
        "UnitTeraByte",
        "UnitPetaByte",
        "UnitByteRate",
        "UnitKiloByteRate",
        "UnitMegaByteRate",
        "UnitGigaByteRate",
        "UnitTeraByteRate",
        "UnitPetaByteRate",
        "UnitHertz",
        "UnitKiloHertz",
        "UnitMegaHertz",
        "UnitGigaHertz",
        "UnitTeraHertz",
        "UnitPetaHertz",
        "UnitBootTimestamp",
        "UnitSecond",
        "UnitTime",
        "UnitTicks",
        "UnitDuration",
        "UnitBitRate",
        "UnitKiloBitRate",
        "UnitMegaBitRate",
        "UnitGigaBitRate",
        "UnitTeraBitRate",
        "UnitPetaBitRate",
        "UnitVolt",
        "UnitKiloVolt",
        "UnitMegaVolt",
        "UnitGigaVolt",
        "UnitTeraVolt",
        "UnitPetaVolt",
        "UnitWatt",
        "UnitKiloWatt",
        "UnitMegaWatt",
        "UnitGigaWatt",
        "UnitTeraWatt",
        "UnitPetaWatt",
        "UnitWattHour",
        "UnitKiloWattHour",
        "UnitMegaWattHour",
        "UnitGigaWattHour",
        "UnitTeraWattHour",
        "UnitPetaWattHour",
        "UnitAmpere",
        "UnitKiloAmpere",
        "UnitMegaAmpere",
        "UnitGigaAmpere",
        "UnitTeraAmpere",
        "UnitPetaAmpere",
        "UnitCelsius",
        "UnitDecibelMilliWatts",
        "UnitPercent",
        "UnitRate",
        "UnitRpm"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'MetricPrefix'
        QtMocHelpers::EnumData<MetricPrefix>(3, 3, QMC::EnumFlags{}).add({
            {    4, MetricPrefix::MetricPrefixAutoAdjust },
            {    5, MetricPrefix::MetricPrefixUnity },
            {    6, MetricPrefix::MetricPrefixKilo },
            {    7, MetricPrefix::MetricPrefixMega },
            {    8, MetricPrefix::MetricPrefixGiga },
            {    9, MetricPrefix::MetricPrefixTera },
            {   10, MetricPrefix::MetricPrefixPeta },
            {   11, MetricPrefix::MetricPrefixLast },
        }),
        // enum 'Unit'
        QtMocHelpers::EnumData<Unit>(12, 12, QMC::EnumFlags{}).add({
            {   13, Unit::UnitInvalid },
            {   14, Unit::UnitNone },
            {   15, Unit::UnitByte },
            {   16, Unit::UnitKiloByte },
            {   17, Unit::UnitMegaByte },
            {   18, Unit::UnitGigaByte },
            {   19, Unit::UnitTeraByte },
            {   20, Unit::UnitPetaByte },
            {   21, Unit::UnitByteRate },
            {   22, Unit::UnitKiloByteRate },
            {   23, Unit::UnitMegaByteRate },
            {   24, Unit::UnitGigaByteRate },
            {   25, Unit::UnitTeraByteRate },
            {   26, Unit::UnitPetaByteRate },
            {   27, Unit::UnitHertz },
            {   28, Unit::UnitKiloHertz },
            {   29, Unit::UnitMegaHertz },
            {   30, Unit::UnitGigaHertz },
            {   31, Unit::UnitTeraHertz },
            {   32, Unit::UnitPetaHertz },
            {   33, Unit::UnitBootTimestamp },
            {   34, Unit::UnitSecond },
            {   35, Unit::UnitTime },
            {   36, Unit::UnitTicks },
            {   37, Unit::UnitDuration },
            {   38, Unit::UnitBitRate },
            {   39, Unit::UnitKiloBitRate },
            {   40, Unit::UnitMegaBitRate },
            {   41, Unit::UnitGigaBitRate },
            {   42, Unit::UnitTeraBitRate },
            {   43, Unit::UnitPetaBitRate },
            {   44, Unit::UnitVolt },
            {   45, Unit::UnitKiloVolt },
            {   46, Unit::UnitMegaVolt },
            {   47, Unit::UnitGigaVolt },
            {   48, Unit::UnitTeraVolt },
            {   49, Unit::UnitPetaVolt },
            {   50, Unit::UnitWatt },
            {   51, Unit::UnitKiloWatt },
            {   52, Unit::UnitMegaWatt },
            {   53, Unit::UnitGigaWatt },
            {   54, Unit::UnitTeraWatt },
            {   55, Unit::UnitPetaWatt },
            {   56, Unit::UnitWattHour },
            {   57, Unit::UnitKiloWattHour },
            {   58, Unit::UnitMegaWattHour },
            {   59, Unit::UnitGigaWattHour },
            {   60, Unit::UnitTeraWattHour },
            {   61, Unit::UnitPetaWattHour },
            {   62, Unit::UnitAmpere },
            {   63, Unit::UnitKiloAmpere },
            {   64, Unit::UnitMegaAmpere },
            {   65, Unit::UnitGigaAmpere },
            {   66, Unit::UnitTeraAmpere },
            {   67, Unit::UnitPetaAmpere },
            {   68, Unit::UnitCelsius },
            {   69, Unit::UnitDecibelMilliWatts },
            {   70, Unit::UnitPercent },
            {   71, Unit::UnitRate },
            {   72, Unit::UnitRpm },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN9KSysGuardE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN9KSysGuardE =
    KSysGuard::qt_create_metaobjectdata<qt_meta_tag_ZN9KSysGuardE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN9KSysGuardE =
    qt_staticMetaObjectContent_ZN9KSysGuardE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN9KSysGuardE =
    qt_staticMetaObjectContent_ZN9KSysGuardE.relocatingData;

Q_CONSTINIT const QMetaObject KSysGuard::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN9KSysGuardE.stringdata,
    qt_staticMetaObjectStaticContent_ZN9KSysGuardE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN9KSysGuardE.metaTypes,
    nullptr
} };

QT_WARNING_POP
